OC.L10N.register(
    "password_policy",
    {
    "Saved" : "Saved",
    "Unknown error" : "Unknown error"
},
"nplurals=1; plural=0;");
